summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/dgn-height.h
diff options
context:
space:
mode:
authorRaphael Langella <raphael.langella@gmail.com>2012-07-10 14:14:29 +0200
committerRaphael Langella <raphael.langella@gmail.com>2012-07-17 01:00:25 +0200
commita4184751df456850d7d5c312c54b62a427d06f3d (patch)
tree2c9886f5d8d00977c7b3ae939a0763b71876cc06 /crawl-ref/source/dgn-height.h
parent410924b6f8f920b2b3f2f0b06a79b14e70e2f874 (diff)
downloadcrawl-ref-a4184751df456850d7d5c312c54b62a427d06f3d.tar.gz
crawl-ref-a4184751df456850d7d5c312c54b62a427d06f3d.zip
Make the Shoals floor brown/yellow depending on height (wet sand).
Brown floor means that it turns to water at high tide (wet sand). Yellow floor is dry, it stays sand at high tide.
Diffstat (limited to 'crawl-ref/source/dgn-height.h')
-rw-r--r--crawl-ref/source/dgn-height.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/crawl-ref/source/dgn-height.h b/crawl-ref/source/dgn-height.h
index 2683ebd2a9..721d574442 100644
--- a/crawl-ref/source/dgn-height.h
+++ b/crawl-ref/source/dgn-height.h
@@ -12,7 +12,8 @@ enum shoals_height_thresholds
SHT_ROCK = 135,
SHT_FLOOR = 0,
SHT_SHALLOW_WATER = -30,
- SHT_SHORE = -18, // sand limit at low tide
+ SHT_SHORE_LOW = -18, // sand limit at low tide
+ SHT_SHORE_HIGH = 24, // sand limit at high tide
};
// The caller is responsible for ensuring that env.heightmap is set.